dhcpkit.ipv6.extensions.prefix_delegation module
================================================

.. automodule:: dhcpkit.ipv6.extensions.prefix_delegation
    :members:
    :undoc-members:
    :show-inheritance:
